@@ -1,21 +1,7 @@
 /*
- *  Copyright 2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "nodeproperties.h"
@@ -136,7 +122,8 @@ void NodeProperties::validateIdInput()
         return;
     }
     int valid = true;
-    foreach (const auto &node, m_node->document()->nodes()) {
+    const auto nodes = m_node->document()->nodes();
+    for (const auto &node : nodes) {
         if (node != m_node && node->id() == ui->id->value()) {
             valid = false;
             break;
@@ -145,7 +132,7 @@ void NodeProperties::validateIdInput()
     // set color
     QPalette palette = ui->id->palette();
     if (valid) {
-        palette.setColor(QPalette::Text, Qt::black);
+        palette = style()->standardPalette();
         m_okButton->setEnabled(true);
         m_okButton->setToolTip(i18nc("@info:tooltip", "The selected ID for this node."));
     } else {
